@@ -71,7 +71,11 @@ class CurrentDependencyProxy(Generic[D]):
         # noinspection PyTypeChecker
         return cls(dependency_type=dependency_type)
 
-    def __init__(self, dependency_type: Type[D], grabber: Callable[[D], Any] = None):
+    def __init__(
+            self, dependency_type: Type[D],
+            grabber: Callable[[D], Any] = None,
+            repr_info: str = None
+    ):
         """
         See `CurrentDependencyProxy` for and overview. Init method doc below.
 
@@ -91,6 +95,10 @@ class CurrentDependencyProxy(Generic[D]):
             grabber: Optional callable, if you wish to grab a specific attribute off the dependency
                 and act like a proxy for that, you can pass in a method here to do so.
                 Whatever is returned from the grabber is what is used to as the object to 'proxy'.
+            repr_info: Will provide this additional info if self gets `repr()` called on it
+                (ie: if used/shown in debugger, etc).
+                Example: Currently used to show the attribute-name/info being proxied when you use
+                `xinject.dependency.Dependency.proxy_attribute`.
         """
 
         # Would give unusual error later on, lets just check right now!
@@ -102,6 +110,7 @@ class CurrentDependencyProxy(Generic[D]):
 
         self._dependency_type = dependency_type
         self._grabber = grabber
+        self._repr_info = repr_info
         pass
 
     def _get_active(self):
@@ -129,7 +138,10 @@ class CurrentDependencyProxy(Generic[D]):
         return setattr(self._get_active(), key, value)
 
     def __repr__(self):
-        return f'CurrentDependencyProxy<{self._get_active().__repr__()}>'
+        info = ''
+        if repr_info := self._repr_info:
+            info = f'({repr_info})'
+        return f'CurrentDependencyProxy{info}<{self._get_active().__repr__()}>'
 
     def __str__(self):
         return self._get_active().__str__()
